var NAVTREEINDEX23 =
{
"structspa__pod__prop.html#a1d32ef4e73f00e16b07a0cecd3f18fe0":[10,8,0,41,0],
"structspa__pod__prop.html#a5f3d78759992c01a760d12743446e8b6":[10,8,0,41,1],
"structspa__pod__prop.html#aa5b6f5944e22f135b02594cc173799bb":[10,8,0,41,2],
"structspa__pod__rectangle.html":[10,8,0,28],
"structspa__pod__rectangle.html#a03b8318f1784bbd03fad4b7187b18c9e":[10,8,0,28,0],
"structspa__pod__rectangle.html#a3599080e445b31f812cc4563be10c2ed":[10,8,0,28,1],
"structspa__pod__sequence.html":[10,8,0,44],
"structspa__pod__sequence.html#abaef5cba65ad23552570ff78c550838f":[10,8,0,44,0],
"structspa__pod__sequence.html#ad699555cf7c8114347524399f2a8b163":[10,8,0,44,1],
"structspa__pod__sequence__body.html":[10,8,0,43],
"structspa__pod__sequence__body.html#adcbb3a7881352555c1a9340662f25c77":[10,8,0,43,1],
"structspa__pod__sequence__body.html#ae83a44c4123cc5dc4450a985d4c4445d":[10,8,0,43,0],
"structspa__pod__string.html":[10,8,0,26],
"structspa__pod__string.html#aa7b8596a64741c1f0b728bc066643c79":[10,8,0,26,0],
"structspa__pod__struct.html":[10,8,0,35],
"structspa__pod__struct.html#a60dbfcf74d9a0dca707123f887817030":[10,8,0,35,0],
"structspa__point.html":[10,8,8,1,2],
"structspa__point.html#a4e7f622b7e262885081e0459bafc22eb":[10,8,8,1,2,1],
"structspa__point.html#ad0e2590c913f99dd1bd9f18aecffc951":[10,8,8,1,2,0],
"structspa__poll__event.html":[10,8,9,7,2],
"structspa__poll__event.html#a9d6d7a42bd3180152807aacb02ddbebe":[10,8,9,7,2,0],
"structspa__poll__event.html#aeed4677e8ecbdfdbe4bad5735e24e570":[10,8,9,7,2,1],
"structspa__port__info.html":[10,8,6,20],
"structspa__port__info.html#a099d9e63a823cd7705ca94b6bcda48d6":[10,8,6,20,1],
"structspa__port__info.html#a0d1d7545d48016fa95629bf71b26c949":[10,8,6,20,2],
"structspa__port__info.html#a3f9832799f2903cdd623d71f958fbc5c":[10,8,6,20,3],
"structspa__port__info.html#a81b330b23307447d948209a19d7a8aee":[10,8,6,20,0],
"structspa__port__info.html#ab6581ff27cf6d9cc624283ba6beed837":[10,8,6,20,4],
"structspa__process__latency__info.html":[10,8,7,26],
"structspa__process__latency__info.html#a1e891c0385d3fb6840019255e4a7bc7f":[10,8,7,26,0],
"structspa__process__latency__info.html#a93fac86cdd1aca91cc5e57a5ea0340fb":[10,8,7,26,1],
"structspa__process__latency__info.html#a97e2de30ab39d818003af3e303049801":[10,8,7,26,2],
"structspa__rectangle.html":[10,8,8,1,1],
"structspa__rectangle.html#a6104eab08e11a0f5f658a5ffd1878068":[10,8,8,1,1,0],
"structspa__rectangle.html#a7510157f1ac054a3dc70c0c6d49083ad":[10,8,8,1,1,1],
"structspa__region.html":[10,8,8,1,3],
"structspa__region.html#a848acf4be0e186e985eafc3b858f0079":[10,8,8,1,3,0],
"structspa__region.html#aac81486ee3a2fbbd52534691bc740f63":[10,8,8,1,3,1],
"structspa__result__device__params.html":[10,8,4,6],
"structspa__result__device__params.html#a19c8bb7f6f09d162006e1a0f0bf98ac9":[10,8,4,6,0],
"structspa__result__device__params.html#a470559d9b427bffac3b8b13a2e06256a":[10,8,4,6,1],
"structspa__result__device__params.html#a9076f671dbf2fe3c8e4c39254f9fe058":[10,8,4,6,2],
"structspa__result__device__params.html#af1baa8eb3700ac09fc9a81a2efd9bebb":[10,8,4,6,3],
"structspa__result__device__params__data.html":[10,8,4,9],
"structspa__result__device__params__data.html#a4b96cf3f827a636bab5ea1ea0a468d38":[10,8,4,9,1],
"structspa__result__device__params__data.html#aacff758b17616a531f27a4b8361142ce":[10,8,4,9,0],
"structspa__result__node__error.html":[10,8,6,21],
"structspa__result__node__error.html#a396020ed7279b7f3293cc2c2eec47485":[10,8,6,21,0],
"structspa__result__node__params.html":[10,8,6,22],
"structspa__result__node__params.html#a16c5fa674ade3d0b6c6d120628b22497":[10,8,6,22,3],
"structspa__result__node__params.html#a9216b607f0684ca0fb5fe0a94c981dc9":[10,8,6,22,2],
"structspa__result__node__params.html#abbef2c04c11cccaed96c8396db5b750f":[10,8,6,22,1],
"structspa__result__node__params.html#af68f44c87bc21f8f92bf59011004e78c":[10,8,6,22,0],
"structspa__result__node__params__data.html":[10,8,6,26],
"structspa__result__node__params__data.html#a8815a2e634f16dff3598e1a2fee6e469":[10,8,6,26,1],
"structspa__result__node__params__data.html#ad11bffd25122b0ca2fef3ac7c360728c":[10,8,6,26,0],
"structspa__ringbuffer.html":[10,8,8,10,1],
"structspa__ringbuffer.html#a6374bbe98fbea037a4479f11cec464c2":[10,8,8,10,1,0],
"structspa__ringbuffer.html#ae7b07eebf6c9f8d3266f46cdffdfca28":[10,8,8,10,1,1],
"structspa__source.html":[10,8,9,4,4],
"structspa__source.html#a3b403afec9c365892ab175f5613a9eff":[10,8,9,4,4,5],
"structspa__source.html#a71de19fa483b3cff326286337642c4f7":[10,8,9,4,4,2],
"structspa__source.html#a97cd32ebf448106e8b3b4791ff691e91":[10,8,9,4,4,6],
"structspa__source.html#ad43d6b5fd83f3e86be4f6103009370cd":[10,8,9,4,4,4],
"structspa__source.html#add060762781a845877ffe088e4bb2a8d":[10,8,9,4,4,1],
"structspa__source.html#ae6a0bb20a4c3b21ae6e622c1685711a8":[10,8,9,4,4,3],
"structspa__source.html#afa3497b4d040a33cacc301d261786306":[10,8,9,4,4,0],
"structspa__support.html":[10,8,9,5,3],
"structspa__support.html#a65463ddc17cb6271875443f52cb7deab":[10,8,9,5,3,1],
"structspa__support.html#adbf0320367c082c9e5e0e4d4b2ab07d5":[10,8,9,5,3,0],
"structspa__system.html":[10,8,9,7,1],
"structspa__system.html#a87fdaae85b7f2321bd10b05a3c9f9b54":[10,8,9,7,1,0],
"structspa__system__methods.html":[10,8,9,7,3],
"structspa__system__methods.html#a13bacd57bc170f5a2342ca95de203ee2":[10,8,9,7,3,10],
"structspa__system__methods.html#a1b6a6ff161066b222f7d1746400c7127":[10,8,9,7,3,18],
"structspa__system__methods.html#a29ed9ebd20b72273a3a6c0a6a6c5a3f1":[10,8,9,7,3,20],
"structspa__system__methods.html#a407f3e0b8a2fa54b40710d965ed83afc":[10,8,9,7,3,11],
"structspa__system__methods.html#a448396798797647ebbf458fca65ef189":[10,8,9,7,3,12],
"structspa__system__methods.html#a4a677665cdba24ec2faf6f471a919fa6":[10,8,9,7,3,17],
"structspa__system__methods.html#a4cb1d67e7262f881d36b5c8a25f4d485":[10,8,9,7,3,16],
"structspa__system__methods.html#a4cd27e2c3a8daa1705da0028af779060":[10,8,9,7,3,1],
"structspa__system__methods.html#a56a305f758899158e90920cf28fd41e4":[10,8,9,7,3,0],
"structspa__system__methods.html#a74ee473681fb6c5c83693d2be53f18db":[10,8,9,7,3,6],
"structspa__system__methods.html#a7a30db95034f05fd2c8c41e78342d500":[10,8,9,7,3,15],
"structspa__system__methods.html#a81c5752082d2ee1f392fe3ae914d7f37":[10,8,9,7,3,4],
"structspa__system__methods.html#a9288a8dd07cf29166a03829e07eb1718":[10,8,9,7,3,7],
"structspa__system__methods.html#a97bdbd157cd2ff98a0ab09b85522960c":[10,8,9,7,3,5],
"structspa__system__methods.html#a9905a87c5474f3a7a6b547999bc7cc7c":[10,8,9,7,3,2],
"structspa__system__methods.html#aae7a5c2f44c9015e351032066498d247":[10,8,9,7,3,8],
"structspa__system__methods.html#abd9d8195afc746c4ef19428491fe00fa":[10,8,9,7,3,14],
"structspa__system__methods.html#abea413fdeedbae46e481fb1c698b81b8":[10,8,9,7,3,19],
"structspa__system__methods.html#ada4083f64959db28b4a03f4032ee87e9":[10,8,9,7,3,13],
"structspa__system__methods.html#adfaee480ca6869161824c85928c0e3d0":[10,8,9,7,3,9],
"structspa__system__methods.html#aea9a9e0adc213e0090a50e3b4883db77":[10,8,9,7,3,3],
"structspa__thread.html":[10,8,9,8,3],
"structspa__thread__utils.html":[10,8,9,8,1],
"structspa__thread__utils.html#add4d911915f7c8e76b9c646389facf70":[10,8,9,8,1,0],
"structspa__thread__utils__methods.html":[10,8,9,8,2],
"structspa__thread__utils__methods.html#a3324347184f8b1caa930012817982c41":[10,8,9,8,2,5],
"structspa__thread__utils__methods.html#a68878e9b02ee15f3590d4c871a97d74a":[10,8,9,8,2,0],
"structspa__thread__utils__methods.html#aa0c4c049d9406510ff457400df373ceb":[10,8,9,8,2,1],
"structspa__thread__utils__methods.html#aa5a251e895f44dd6f48ee3014f0546e4":[10,8,9,8,2,3],
"structspa__thread__utils__methods.html#ab1126024161570f88d077ecee01066e8":[10,8,9,8,2,2],
"structspa__thread__utils__methods.html#adaa8eb3e63f991d91dbb6246fd4f6c3e":[10,8,9,8,2,4],
"structspa__type__info.html":[10,8,8,12,2],
"structspa__type__info.html#a25dfe56fe53d756509cd5daa5f5b64e5":[10,8,8,12,2,0],
"structspa__type__info.html#ab94f9983f18d62536d03ba5eb7db9bae":[10,8,8,12,2,1],
"structspa__type__info.html#afedc2465e18bf4d93bf2a3d8afcc4c13":[10,8,8,12,2,2],
"structspa__video__colorimetry.html":[10,8,7,28],
"structspa__video__colorimetry.html#a59be293b53b9bda54a7e3269facb1cf2":[10,8,7,28,0],
"structspa__video__colorimetry.html#aa2b220b0a2586562f3547505f851fd21":[10,8,7,28,1],
"structspa__video__colorimetry.html#aba452a4ed2b7424b2399971e8c1444bb":[10,8,7,28,2],
"structspa__video__colorimetry.html#ae40f82c41e61be82a9697a872d83479e":[10,8,7,28,3],
"structspa__video__info.html":[10,8,7,31],
"structspa__video__info.html#a0e442291121d1e295e2db47ead38eb11":[10,8,7,31,5],
"structspa__video__info.html#a429e55f4dde148559d032bcaf8cd73f0":[10,8,7,31,1],
"structspa__video__info.html#a697a0106c54d5680d0cfd2731b60d712":[10,8,7,31,2],
"structspa__video__info.html#a73d52ad69db77b05afa52a8cb61455c9":[10,8,7,31,0],
"structspa__video__info.html#ab2856db92b8c85f902b4be0390dd2141":[10,8,7,31,4],
"structspa__video__info.html#ae560fd469ae20166eda82b4efe2ce67d":[10,8,7,31,6],
"structspa__video__info.html#afe7b9fde171f232f0b7eb76778845784":[10,8,7,31,3],
"structspa__video__info__dsp.html":[10,8,7,33],
"structspa__video__info__dsp.html#a3b770cfcdcc6cf56ce7f887e7408f374":[10,8,7,33,1],
"structspa__video__info__dsp.html#ada698c22ed974fa690ff6ee37855e659":[10,8,7,33,0],
"structspa__video__info__h264.html":[10,8,7,29],
"structspa__video__info__h264.html#a1489a7d7ede99a9ae6bbd9a681702764":[10,8,7,29,4],
"structspa__video__info__h264.html#a689431f4e474ea4e2190992318cb9134":[10,8,7,29,0],
"structspa__video__info__h264.html#a6f66987d4fc4c666153db915c55904d2":[10,8,7,29,1],
"structspa__video__info__h264.html#aabf20435e02dd88a09243ab0480cb0a8":[10,8,7,29,3],
"structspa__video__info__h264.html#af680ca708a6fac71a3236cb73e1e1fc1":[10,8,7,29,2],
"structspa__video__info__mjpg.html":[10,8,7,30],
"structspa__video__info__mjpg.html#a79a7bc729e3b98faa7285d6475b9867b":[10,8,7,30,2],
"structspa__video__info__mjpg.html#ab9036a7d67f3441634c59d4f498dfb1d":[10,8,7,30,1],
"structspa__video__info__mjpg.html#ad383b32a6c8709d413fa0ac3b35a6985":[10,8,7,30,0],
"structspa__video__info__raw.html":[10,8,7,32],
"structspa__video__info__raw.html#a0add074733e5354cfea4f633b23feeec":[10,8,7,32,14],
"structspa__video__info__raw.html#a1b34707c39ebadbae7550a997a29bf5f":[10,8,7,32,13],
"structspa__video__info__raw.html#a25b3f0682ca30d079c005868650c23ed":[10,8,7,32,6],
"structspa__video__info__raw.html#a371bed1caf6cc1ffbbdd6bae58883d59":[10,8,7,32,2],
"structspa__video__info__raw.html#a37a68aa68e7ce91c4d8da20437664b19":[10,8,7,32,11],
"structspa__video__info__raw.html#a3bedf6a844bdca773ab5840615f87d73":[10,8,7,32,7],
"structspa__video__info__raw.html#a48a1b5480465ffdcee2dfa9e95ed47fb":[10,8,7,32,8],
"structspa__video__info__raw.html#a4f6cf0e98b78c96384b6ffb372e2d9db":[10,8,7,32,5],
"structspa__video__info__raw.html#a73891e491000758f521c9b701f8cfeaf":[10,8,7,32,3],
"structspa__video__info__raw.html#a99a7b7e3ccd534510cb33036028edd7e":[10,8,7,32,9],
"structspa__video__info__raw.html#acc3883d98af70282cb7536274e0edd74":[10,8,7,32,1],
"structspa__video__info__raw.html#ad417a8eb76373dd414e0f76662e2ead6":[10,8,7,32,0],
"structspa__video__info__raw.html#ad56c11bdb72352e9407e39535b55deed":[10,8,7,32,12],
"structspa__video__info__raw.html#af59a82989f29004917bb4f62b003addb":[10,8,7,32,4],
"structspa__video__info__raw.html#af85622f27e56fe5ce8675d2523d93884":[10,8,7,32,10],
"system_8h.html":[10,8,9,7,0],
"thread-loop_8h.html":[10,5,15,0],
"tutorial1_8c-example.html":[13,0],
"tutorial2_8c-example.html":[13,1],
"tutorial3_8c-example.html":[13,2],
"tutorial4_8c-example.html":[13,3],
"tutorial5_8c-example.html":[13,4],
"tutorial6_8c-example.html":[13,5],
"types_8h.html":[10,8,3,7],
"utils_2dict_8h.html":[10,8,8,2,0],
"utils_2type-info_8h.html":[10,8,8,12,0],
"vararg_8h.html":[10,8,0,8],
"video-dsp-play_8c-example.html":[13,12],
"video-play-fixate_8c-example.html":[13,18],
"video-play-pull_8c-example.html":[13,13],
"video-play-reneg_8c-example.html":[13,14],
"video-play_8c-example.html":[13,10],
"video-src-alloc_8c-example.html":[13,15],
"video-src-fixate_8c-example.html":[13,17],
"video-src-reneg_8c-example.html":[13,16],
"video-src_8c-example.html":[13,11],
"video_2raw_8h.html":[10,8,7,17],
"work-queue_8h.html":[10,5,16,0]
};
